pub struct DaemonController { /* private fields */ }
Controller to manage registered filesystem/blobcache/fscache services.

Implementations

source

impl DaemonController

source

pub fn new() -> DaemonController

Create a new instance of DaemonController.

source

pub fn is_active(&self) -> bool

Check whether the service controller is still in active/working state.

source

pub fn alloc_waker(&self) -> Arc<Waker>

Allocate a waker to notify stop events.

source

pub fn set_singleton_mode(&self, enabled: bool)

Enable/disable singleton mode.

source

pub fn set_daemon( &self, daemon: Arc<dyn NydusDaemon + 'static> ) -> Option<Arc<dyn NydusDaemon + 'static>>

Set the daemon service object.

source

pub fn get_daemon(&self) -> Arc<dyn NydusDaemon + 'static>

Get the daemon service object.

Panic if called before set_daemon() has been called.

source

pub fn get_blob_cache_mgr(&self) -> Option<Arc<BlobCacheMgr>>

Get the optional blob cache manager.

source

pub fn set_blob_cache_mgr( &self, mgr: Arc<BlobCacheMgr> ) -> Option<Arc<BlobCacheMgr>>

Set the optional blob cache manager.

source

pub fn set_fs_service( &self, service: Arc<dyn FsService + 'static> ) -> Option<Arc<dyn FsService + 'static>>

Set the default fs service object.

source

pub fn get_fs_service(&self) -> Option<Arc<dyn FsService + 'static>>

Get the default fs service object.

source

pub fn shutdown(&self)

Shutdown all services managed by the controller.

source

pub fn run_loop(&self)

Run the event loop to handle service management events.