Struct nydus::daemon::DaemonStateMachine
source · pub struct DaemonStateMachine;Trait Implementations
sourceimpl Clone for DaemonStateMachine
impl Clone for DaemonStateMachine
sourcefn clone(&self) -> DaemonStateMachine
fn clone(&self) -> DaemonStateMachine
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DaemonStateMachine
impl Debug for DaemonStateMachine
sourceimpl StateMachineImpl for DaemonStateMachine
impl StateMachineImpl for DaemonStateMachine
type Input = DaemonStateMachineInput
type Input = DaemonStateMachineInput
The input alphabet.
type State = DaemonStateMachineState
type State = DaemonStateMachineState
The set of possible states.
type Output = DaemonStateMachineOutput
type Output = DaemonStateMachineOutput
The output alphabet.
sourceconst INITIAL_STATE: <DaemonStateMachine as StateMachineImpl>::State = {transmute(0x01): <nydus_service::daemon::DaemonStateMachine as rust_fsm::StateMachineImpl>::State}
const INITIAL_STATE: <DaemonStateMachine as StateMachineImpl>::State = {transmute(0x01): <nydus_service::daemon::DaemonStateMachine as rust_fsm::StateMachineImpl>::State}
The initial state of the machine.
sourcefn transition(
state: &<DaemonStateMachine as StateMachineImpl>::State,
input: &<DaemonStateMachine as StateMachineImpl>::Input
) -> Option<<DaemonStateMachine as StateMachineImpl>::State>
fn transition( state: &<DaemonStateMachine as StateMachineImpl>::State, input: &<DaemonStateMachine as StateMachineImpl>::Input ) -> Option<<DaemonStateMachine as StateMachineImpl>::State>
The transition fuction that outputs a new state based on the current
state and the provided input. Outputs
None when there is no transition
for a given combination of the input and the state.sourcefn output(
state: &<DaemonStateMachine as StateMachineImpl>::State,
input: &<DaemonStateMachine as StateMachineImpl>::Input
) -> Option<<DaemonStateMachine as StateMachineImpl>::Output>
fn output( state: &<DaemonStateMachine as StateMachineImpl>::State, input: &<DaemonStateMachine as StateMachineImpl>::Input ) -> Option<<DaemonStateMachine as StateMachineImpl>::Output>
The output function that outputs some value from the output alphabet
based on the current state and the given input. Outputs
None when
there is no output for a given combination of the input and the state.